==> pandoc-crossref-0.3.19-172-loong64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-LPJua0lBLrWCQ9cCo9rK5h-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-LPJua0lBLrWCQ9cCo9rK5h-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  7585f7b669332943efefb5c2d86b65e7
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-LPJua0lBLrWCQ9cCo9rK5h-pandoc-crossref-internal

depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    pandoc-3.5-55SkYSUzRIiB5PVZOvExG3
    pandoc-types-1.23.1-8LyhSCLdqfo18RNKTPAafp
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp template-haskell-2.20.0.0
    text-2.0.2 utility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-7knXUqaeFPmGY2swZtqWW2
key:                  pandoc-crossref-0.3.19-7knXUqaeFPmGY2swZtqWW2
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  ed3c6d4a258a9ecbd85e975a7f3f683b
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-7knXUqaeFPmGY2swZtqWW2
depends:
    base-4.18.2.1 mtl-2.3.1 pandoc-3.5-55SkYSUzRIiB5PVZOvExG3
    pandoc-crossref-0.3.19-LPJua0lBLrWCQ9cCo9rK5h-pandoc-crossref-internal
    pandoc-types-1.23.1-8LyhSCLdqfo18RNKTPAafp text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.19-175-loong64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-G8p7jIWerP1FSDWQaIpDx6-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-G8p7jIWerP1FSDWQaIpDx6-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  39ac5736afdf8844a357221f30ac829d
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-G8p7jIWerP1FSDWQaIpDx6-pandoc-crossref-internal

depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl directory-1.3.8.5
    filepath-1.4.300.1 microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    pandoc-3.5-5SF7KFwug7mFO7qlpyjx0e
    pandoc-types-1.23.1-CJH803wvmoH5NkoCOHPWhx
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL template-haskell-2.20.0.0
    text-2.0.2 utility-ht-0.0.17.2-BA4bKaVbHll1pHS0NgHkhL

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-9CNQd1fYUDs3ShNmqvLQ8T
key:                  pandoc-crossref-0.3.19-9CNQd1fYUDs3ShNmqvLQ8T
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  291f4b1951a84bfa5852fdf9635f2746
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-9CNQd1fYUDs3ShNmqvLQ8T
depends:
    base-4.18.2.1 mtl-2.3.1 pandoc-3.5-5SF7KFwug7mFO7qlpyjx0e
    pandoc-crossref-0.3.19-G8p7jIWerP1FSDWQaIpDx6-pandoc-crossref-internal
    pandoc-types-1.23.1-CJH803wvmoH5NkoCOHPWhx text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
